@@ -558,8 +558,6 @@ bdb_lookup(const char *zone, const char *name, void *driverarg,
 		host_cursor->c_close(host_cursor);
 
 	return result;
-
-	return ISC_R_NOTFOUND;
 }
 
 
@@ -744,7 +742,14 @@ static dns_sdlzmethods_t dlz_bdb_methods = {
 	bdb_lookup,
 	NULL,
 	bdb_allnodes,
-	bdb_allowzonexfr
+	bdb_allowzonexfr,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
 };
 
 /*%
